@@ -1,10 +1,12 @@
+import logging
 from datetime import datetime
-from typing import Annotated, Any
+from typing import Any
 
-from pydantic import BaseModel, BeforeValidator, field_validator
+from pydantic import BaseModel, field_validator
 
 from b24api.error import ApiResponseError, RetryApiResponseError
 from b24api.query import build_query
+from b24api.settings import Settings
 from b24api.type import ApiTypes
 
 
@@ -57,17 +59,19 @@ class ErrorResponse(BaseModel):
             value = value.lower()
         return value
 
-    def raise_error(self, request: Request, retry_errors: list[str]) -> None:
-        if self.error in retry_errors:
-            raise RetryApiResponseError(
-                code=self.error,
-                description=self.error_description,
-                request=str(request),
-            )
-        raise ApiResponseError(
+    def raise_error(self, request: Request, settings: Settings) -> None:
+        logger = logging.getLogger(settings.logger_name)
+
+        if self.error in settings.retry_errors:
+            logger.debug("Request: %s", request)
+            error_cls = RetryApiResponseError
+        else:
+            logger.warning("Request: %s", request)
+            error_cls = ApiResponseError
+
+        raise error_cls(
             code=self.error,
             description=self.error_description,
-            request=str(request),
         )
 
 
@@ -92,18 +96,50 @@ class Response(BaseModel):
     total: int | None = None
     next: int | None = None
 
+    @property
+    def list_result(self) -> list[ApiTypes]:
+        """Fix `list` methods result to `list of items` structure.
 
-def _php_dict(value: Any) -> Any:  # noqa: ANN401
-    if isinstance(value, list) and not value:
-        return {}
-    return value
+        There are two kinds of what `list` method `result` may contain:
+        - a list of items (e.g. `department-get` and `disk.folder.getchildren`),
+        - a dictionary with single item that contains the desired list of items
+            (e.g. `tasks` in `tasks.task.list`).
+        """
+        if not isinstance(self.result, list | dict):
+            raise TypeError(f"Expecting `result` to be a `list` or a `dict`. Got: {self.result}")
+
+        if not self.result:
+            return []
+
+        if isinstance(self.result, list):
+            return self.result
+
+        if len(self.result) != 1:
+            raise TypeError(
+                f"If `result` is a `dict`, expecting single item. Got: {self.result}",
+            )
+
+        key = next(iter(self.result))
+        value = self.result[key]
+
+        if not isinstance(value, list):
+            raise TypeError(f"If `result` is a `dict`, expecting single item to be a `list`. Got: {self.result}")
+
+        return value
 
 
 class BatchResult(BaseModel):
     """API response `result` structure for `batch` method."""
 
-    result: Annotated[dict[str, ApiTypes], BeforeValidator(_php_dict)]
-    result_time: Annotated[dict[str, ResponseTime], BeforeValidator(_php_dict)]
-    result_error: Annotated[dict[str, ErrorResponse], BeforeValidator(_php_dict)]
-    result_total: Annotated[dict[str, int], BeforeValidator(_php_dict)]
-    result_next: Annotated[dict[str, int], BeforeValidator(_php_dict)]
+    result: dict[str, ApiTypes]
+    result_time: dict[str, ResponseTime]
+    result_error: dict[str, ErrorResponse]
+    result_total: dict[str, int]
+    result_next: dict[str, int]
+
+    @field_validator("result", "result_time", "result_error", "result_total", "result_next", mode="before")
+    @classmethod
+    def php_dict(cls, value: Any) -> Any:  # noqa: ANN401
+        if isinstance(value, list) and not value:
+            return {}
+        return value
